@@ -6,11 +6,14 @@
 
 mod allocator;
 mod atomic_shared_address;
+mod atomic_shared_address_range;
 mod object_offset;
 mod object_size;
 mod shared_address;
 mod shared_address_range;
 mod shared_box;
+mod shared_channel;
+mod shared_option;
 mod shared_rc;
 mod shared_vec;
 mod shmem_id;
@@ -19,10 +22,17 @@ mod shmem_name;
 // All unsafe code lives here
 mod unsafe_code;
 
+// Reexport traits.
+pub use shared_memory::SharedMemCast;
+
 pub use allocator::get_bootstrap_name;
 pub use allocator::set_bootstrap_name;
 pub use shared_address_range::SharedAddressRange;
 pub use shared_box::SharedBox;
+pub use shared_channel::channel;
+pub use shared_channel::SharedReceiver;
+pub use shared_channel::SharedSender;
+pub use shared_option::SharedOption;
 pub use shared_rc::SharedRc;
 pub use shared_vec::SharedVec;
 pub use unsafe_code::SharedMemRef;
@@ -32,6 +42,7 @@ pub use unsafe_code::Volatile;
 pub(crate) use allocator::ShmemAllocator;
 pub(crate) use allocator::ALLOCATOR;
 pub(crate) use atomic_shared_address::AtomicSharedAddress;
+pub(crate) use atomic_shared_address_range::AtomicSharedAddressRange;
 pub(crate) use object_offset::ObjectOffset;
 pub(crate) use object_size::ObjectSize;
 pub(crate) use shared_address::SharedAddress;
